@@ -18,6 +18,7 @@
 
 from __future__ import annotations
 
+import contextlib
 import time
 from copy import deepcopy
 from datetime import datetime as dt
@@ -237,7 +238,9 @@ class CustomObjectLauncher(LoggingMixin):
 
     def get_body(self):
         self.body: dict = SparkJobSpec(**self.template_body["spark"])
-        self.body.metadata = {"name": self.name, "namespace": self.namespace}
+        if not hasattr(self.body, "metadata") or not isinstance(self.body.metadata, dict):
+            self.body.metadata = {}
+        self.body.metadata.update({"name": self.name, "namespace": self.namespace})
         if self.template_body.get("kubernetes"):
             k8s_spec: dict = KubernetesSpec(**self.template_body["kubernetes"])
             self.body.spec["volumes"] = k8s_spec.volumes
@@ -326,12 +329,10 @@ class CustomObjectLauncher(LoggingMixin):
         driver_state = spark_job_info.get("status", {}).get("applicationState", {}).get("state", "SUBMITTED")
         if driver_state == CustomObjectStatus.FAILED:
             err = spark_job_info.get("status", {}).get("applicationState", {}).get("errorMessage", "N/A")
-            try:
+            with contextlib.suppress(Exception):
                 self.pod_manager.fetch_container_logs(
                     pod=self.pod_spec, container_name="spark-kubernetes-driver"
                 )
-            except Exception:
-                pass
             raise AirflowException(f"Spark Job Failed. Error stack: {err}")
         return driver_state == CustomObjectStatus.SUBMITTED
 
