@@ -27,6 +27,7 @@ from unittest.mock import MagicMock, PropertyMock, patch
 import anyio
 import kubernetes
 import pytest
+import pytest_asyncio
 import yaml
 from kubernetes.client import V1Deployment, V1DeploymentStatus
 from kubernetes.client.rest import ApiException
@@ -437,11 +438,10 @@ class TestKubernetesHook:
             mock_get_client.assert_called_with(cluster_context="test")
             assert kubernetes_hook.get_namespace() == "test"
 
-    def test_missing_default_connection_is_ok(self, remove_default_conn):
+    def test_missing_default_connection_is_ok(self, remove_default_conn, sdk_connection_not_found):
         # prove to ourselves that the default conn doesn't exist
         k8s_conn_exists = os.environ.get(f"AIRFLOW_CONN_{DEFAULT_CONN_ID.upper()}")
         assert k8s_conn_exists is None
-
         # verify K8sHook still works
         hook = KubernetesHook()
         assert hook.conn_extras == {}
@@ -762,7 +762,7 @@ class TestKubernetesHook:
     def test_check_kueue_deployment_raise_exception(self, mock_get_deployment_status, mock_log):
         mock_get_deployment_status.side_effect = ValueError
 
-        with pytest.raises(ValueError):
+        with pytest.raises(ValueError, match="Exception occurred while checking for Deployment status"):
             KubernetesHook().check_kueue_deployment_running(name=DEPLOYMENT_NAME, namespace=NAMESPACE)
 
         mock_log.exception.assert_called_once_with("Exception occurred while checking for Deployment status.")
@@ -847,8 +847,8 @@ class TestAsyncKubernetesHook:
         f.set_result(return_value)
         return f
 
-    @pytest.fixture
-    def kube_config_loader(self):
+    @pytest_asyncio.fixture
+    async def kube_config_loader(self):
         with mock.patch(self.KUBE_LOADER_CONFIG) as kube_config_loader:
             kube_config_loader.return_value.load_and_set.return_value = self.mock_await_result(None)
             yield kube_config_loader
@@ -1000,9 +1000,7 @@ class TestAsyncKubernetesHook:
         assert kube_client is None
 
     @pytest.mark.asyncio
-    async def test_load_config_with_several_params(
-        self,
-    ):
+    async def test_load_config_with_several_params(self, sdk_connection_not_found):
         hook = AsyncKubernetesHook(
             conn_id=CONN_ID,
             in_cluster=True,
