@@ -19,7 +19,6 @@ from __future__ import annotations
 import logging
 from datetime import datetime
 from json.decoder import JSONDecodeError
-from types import SimpleNamespace
 from typing import TYPE_CHECKING, cast
 from unittest import mock
 from unittest.mock import MagicMock, PropertyMock
@@ -35,9 +34,6 @@ from airflow.providers.cncf.kubernetes.utils.pod_manager import (
     PodLogsConsumer,
     PodManager,
     PodPhase,
-    container_is_running,
-    container_is_succeeded,
-    container_is_terminated,
 )
 from airflow.utils.timezone import utc
 
@@ -173,7 +169,7 @@ class TestPodManager:
         startup_check_interval = 10
 
         def mock_read_pod_events(pod):
-            self.pod_manager.keep_watching_for_events = False
+            self.pod_manager.stop_watching_events = True
             return events
 
         with (
@@ -514,7 +510,7 @@ class TestPodManager:
         assert mock_time_sleep.call_count == 3
         assert f"::group::Waiting until {schedule_timeout}s to get the POD scheduled..." in caplog.text
         assert f"Waiting {startup_timeout}s to get the POD running..." in caplog.text
-        assert not self.pod_manager.keep_watching_for_events
+        assert self.pod_manager.stop_watching_events is True
 
     @mock.patch("airflow.providers.cncf.kubernetes.utils.pod_manager.container_is_running")
     def test_container_is_running(self, container_is_running_mock):
@@ -611,24 +607,6 @@ class TestPodManager:
         assert ret.last_log_time == pendulum.datetime(2021, 1, 1, tz="UTC")
         assert ret.running is exp_running
 
-    @pytest.mark.parametrize(
-        "container_state, expected_is_terminated",
-        [("waiting", False), ("running", False), ("terminated", True)],
-    )
-    def test_container_is_terminated_with_waiting_state(self, container_state, expected_is_terminated):
-        container_status = MagicMock()
-        container_status.configure_mock(
-            **{
-                "name": "base",
-                "state.waiting": True if container_state == "waiting" else None,
-                "state.running": True if container_state == "running" else None,
-                "state.terminated": True if container_state == "terminated" else None,
-            }
-        )
-        pod_info = MagicMock()
-        pod_info.status.container_statuses = [container_status]
-        assert container_is_terminated(pod_info, "base") == expected_is_terminated
-
     @mock.patch("airflow.providers.cncf.kubernetes.utils.pod_manager.kubernetes_stream")
     @mock.patch("airflow.providers.cncf.kubernetes.utils.pod_manager.PodManager.extract_xcom_kill")
     def test_extract_xcom_success(self, mock_exec_xcom_kill, mock_kubernetes_stream):
@@ -722,66 +700,6 @@ class TestPodManager:
         mock_container_is_running.assert_any_call(mock_pod, "airflow-xcom-sidecar")
 
 
-def params_for_test_container_is_running():
-    """The `container_is_running` method is designed to handle an assortment of bad objects
-    returned from `read_pod`.  E.g. a None object, an object `e` such that `e.status` is None,
-    an object `e` such that `e.status.container_statuses` is None, and so on.  This function
-    emits params used in `test_container_is_running` to verify this behavior.
-
-    We create mock classes not derived from MagicMock because with an instance `e` of MagicMock,
-    tests like `e.hello is not None` are always True.
-    """
-
-    class RemotePodMock:
-        pass
-
-    class ContainerStatusMock:
-        def __init__(self, name):
-            self.name = name
-
-    def remote_pod(running=None, not_running=None):
-        e = RemotePodMock()
-        e.status = RemotePodMock()
-        e.status.container_statuses = []
-        e.status.init_container_statuses = []
-        for r in not_running or []:
-            e.status.container_statuses.append(container(r, False))
-        for r in running or []:
-            e.status.container_statuses.append(container(r, True))
-        return e
-
-    def container(name, running):
-        c = ContainerStatusMock(name)
-        c.state = RemotePodMock()
-        c.state.running = {"a": "b"} if running else None
-        return c
-
-    pod_mock_list = []
-    pod_mock_list.append(pytest.param(None, False, id="None remote_pod"))
-    p = RemotePodMock()
-    p.status = None
-    pod_mock_list.append(pytest.param(p, False, id="None remote_pod.status"))
-    p = RemotePodMock()
-    p.status = RemotePodMock()
-    p.status.container_statuses = []
-    p.status.init_container_statuses = []
-    pod_mock_list.append(pytest.param(p, False, id="empty remote_pod.status.container_statuses"))
-    pod_mock_list.append(pytest.param(remote_pod(), False, id="filter empty"))
-    pod_mock_list.append(pytest.param(remote_pod(None, ["base"]), False, id="filter 0 running"))
-    pod_mock_list.append(pytest.param(remote_pod(["hello"], ["base"]), False, id="filter 1 not running"))
-    pod_mock_list.append(pytest.param(remote_pod(["base"], ["hello"]), True, id="filter 1 running"))
-    return pod_mock_list
-
-
-@pytest.mark.parametrize("remote_pod, result", params_for_test_container_is_running())
-def test_container_is_running(remote_pod, result):
-    """The `container_is_running` function is designed to handle an assortment of bad objects
-    returned from `read_pod`.  E.g. a None object, an object `e` such that `e.status` is None,
-    an object `e` such that `e.status.container_statuses` is None, and so on.  This test
-    verifies the expected behavior."""
-    assert container_is_running(remote_pod, "base") is result
-
-
 class TestPodLogsConsumer:
     @pytest.mark.parametrize(
         "chunks, expected_logs",
@@ -958,68 +876,3 @@ class TestPodLogsConsumer:
         # second read
         with time_machine.travel(mock_read_pod_at_1):
             assert consumer.read_pod() == expected_read_pods[1]
-
-
-def params_for_test_container_is_succeeded():
-    """The `container_is_succeeded` method is designed to handle an assortment of bad objects
-    returned from `read_pod`.  E.g. a None object, an object `e` such that `e.status` is None,
-    an object `e` such that `e.status.container_statuses` is None, and so on.  This function
-    emits params used in `test_container_is_succeeded` to verify this behavior.
-    We create mock classes not derived from MagicMock because with an instance `e` of MagicMock,
-    tests like `e.hello is not None` are always True.
-    """
-
-    class RemotePodMock:
-        pass
-
-    class ContainerStatusMock:
-        def __init__(self, name):
-            self.name = name
-
-    def remote_pod(succeeded=None, not_succeeded=None):
-        e = RemotePodMock()
-        e.status = RemotePodMock()
-        e.status.container_statuses = []
-        e.status.init_container_statuses = []
-        for r in not_succeeded or []:
-            e.status.container_statuses.append(container(r, False))
-        for r in succeeded or []:
-            e.status.container_statuses.append(container(r, True))
-        return e
-
-    def container(name, succeeded):
-        c = ContainerStatusMock(name)
-        c.state = RemotePodMock()
-        c.state.terminated = SimpleNamespace(**{"exit_code": 0}) if succeeded else None
-        return c
-
-    pod_mock_list = []
-    pod_mock_list.append(pytest.param(None, False, id="None remote_pod"))
-    p = RemotePodMock()
-    p.status = None
-    pod_mock_list.append(pytest.param(p, False, id="None remote_pod.status"))
-    p = RemotePodMock()
-    p.status = RemotePodMock()
-    p.status.container_statuses = None
-    p.status.init_container_statuses = []
-
-    pod_mock_list.append(pytest.param(p, False, id="None remote_pod.status.container_statuses"))
-    p = RemotePodMock()
-    p.status = RemotePodMock()
-    p.status.container_statuses = []
-    p.status.init_container_statuses = []
-    pod_mock_list.append(pytest.param(p, False, id="empty remote_pod.status.container_statuses"))
-    pod_mock_list.append(pytest.param(remote_pod(), False, id="filter empty"))
-    pod_mock_list.append(pytest.param(remote_pod(None, ["base"]), False, id="filter 0 succeeded"))
-    pod_mock_list.append(pytest.param(remote_pod(["hello"], ["base"]), False, id="filter 1 not succeeded"))
-    pod_mock_list.append(pytest.param(remote_pod(["base"], ["hello"]), True, id="filter 1 succeeded"))
-    return pod_mock_list
-
-
-@pytest.mark.parametrize("remote_pod, result", params_for_test_container_is_succeeded())
-def test_container_is_succeeded(remote_pod, result):
-    """The `container_is_succeeded` function is designed to handle an assortment of bad objects
-    returned from `read_pod`.  E.g. a None object, an object `e` such that `e.status` is None,
-    an object `e` such that `e.status.container_statuses` is None, and so on.  This test
-    verifies the expected behavior."""
-    assert container_is_succeeded(remote_pod, "base") is result
